Welcome to ``SDyPy-io`` documentation!
======================================

This is the documentation for the ``SDyPy-io`` package, part of ``SDyPy`` framework_. Check out the project on GitHub_.

To use the package, install the ``sdypy`` package:

.. code:: bash

   pip install sdypy

The ``io`` module is imported as follows:

.. code:: python

   from sdypy import io


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   uff
   lvm
   mraw


.. _GitHub: https://github.com/sdypy/sdypy-io
.. _framework: https://github.com/sdypy